@@ -1,22 +1,30 @@
 import networkx as nx
-from typing import Any, Union, TypeVar, Dict, List
-from typing_extensions import TypedDict, Literal, NotRequired
+from typing import Any, Union, Dict, List, Iterable
+from typing_extensions import TypedDict, Literal, NotRequired, Protocol
 from pathlib import Path
 from io import IOBase
 
+from pelote.shim import pd
+
 # Misc utils
 FileHandle = Union[str, Path, IOBase]
 
-# Networkx-related
-NodeKey = TypeVar("NodeKey")
 
+class Indexable(Protocol):
+    def __getitem__(self, key: Any) -> Any:
+        ...
+
+
+Tabular = Union["pd.DataFrame", Iterable[Indexable]]
+
+# Networkx-related
 AnyGraph = Union[
     nx.Graph,
     nx.DiGraph,
     nx.MultiGraph,
     nx.MultiDiGraph,
 ]
-
+Attributes = Dict[Any, Any]
 
 # Graphology serialization
 SerializedAttributes = Dict[str, Any]
